@@ -24,6 +24,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_iam
@@ -68,6 +70,9 @@ class KinesisDestination(
         :param stream: The Kinesis stream to use as destination.
         :param role: The role to assume to write log events to the destination. Default: - A new Role is created
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisDestination.__init__)
+            check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
         props = KinesisDestinationProps(role=role)
 
         jsii.create(self.__class__, self, [stream, props])
@@ -90,6 +95,10 @@ class KinesisDestination(
         :param scope: -
         :param _source_log_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisDestination.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument _source_log_group", value=_source_log_group, expected_type=type_hints["_source_log_group"])
         return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, _source_log_group]))
 
 
@@ -119,6 +128,9 @@ class KinesisDestinationProps:
                 role=role
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisDestinationProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -178,6 +190,9 @@ class LambdaDestination(
         :param fn: -
         :param add_permissions: Whether or not to add Lambda Permissions. Default: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaDestination.__init__)
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         options = LambdaDestinationOptions(add_permissions=add_permissions)
 
         jsii.create(self.__class__, self, [fn, options])
@@ -200,6 +215,10 @@ class LambdaDestination(
         :param scope: -
         :param log_group: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaDestination.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
         return typing.cast(aws_cdk.aws_logs.LogSubscriptionDestinationConfig, jsii.invoke(self, "bind", [scope, log_group]))
 
 
@@ -230,6 +249,9 @@ class LambdaDestinationOptions:
                 add_permissions=False
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaDestinationOptions.__init__)
+            check_type(argname="argument add_permissions", value=add_permissions, expected_type=type_hints["add_permissions"])
         self._values: typing.Dict[str, typing.Any] = {}
         if add_permissions is not None:
             self._values["add_permissions"] = add_permissions
